pub struct ErrorLocation { /* private fields */ }Implementations
Sourceimpl ErrorLocation
impl ErrorLocation
Sourcepub fn into_owned(self) -> ErrorLocation
pub fn into_owned(self) -> ErrorLocation
Copy the structure and clone the original values if it’s not owned.
This is always a deep copy of the structure.